==> 0.5.4.tar.gz: android/src/main/java/com/samelement/iot_notification/service/MqttExceptionMessage.java <==
package com.samelement.iot_notification.service;

import org.eclipse.paho.client.mqttv3.MqttException;

public class MqttExceptionMessage {
    static String getMessage(MqttException exception, int reasonCode) {
        switch (reasonCode) {
            case MqttException.REASON_CODE_CLIENT_EXCEPTION:
                if (exception != null && exception.getCause() != null) {
                    return exception.getCause().getMessage();
                } else if (exception != null && exception.getMessage() != null && !exception.getMessage().isEmpty()) {
                    return exception.getMessage();
                } else return "Client encountered an exception";
            case MqttException.REASON_CODE_CONNECTION_LOST:
                if (exception != null && exception.getCause() != null) {
                    return exception.getCause().getMessage();
                } else if (exception != null && exception.getMessage() != null && !exception.getMessage().isEmpty()) {
                    return exception.getMessage();
                } else return "The client has been unexpectedly disconnected from the server";
            case MqttException.REASON_CODE_INVALID_PROTOCOL_VERSION:
                return "The protocol version requested is not supported by the server";
            case MqttException.REASON_CODE_INVALID_CLIENT_ID:
                return "The server has rejected the supplied client ID";
            case MqttException.REASON_CODE_BROKER_UNAVAILABLE:
                return "The broker was not available to handle the request";
            case MqttException.REASON_CODE_FAILED_AUTHENTICATION:
                return "Authentication with the server has failed, due to a bad user name or password";
            case MqttException.REASON_CODE_NOT_AUTHORIZED:
                return "Not authorized to perform the requested operation";
            case MqttException.REASON_CODE_UNEXPECTED_ERROR:
                return "An unexpected error has occurred";
            case MqttException.REASON_CODE_SUBSCRIBE_FAILED:
                return "Error from subscribe - returned from the server";
            case MqttException.REASON_CODE_CLIENT_TIMEOUT:
                return "Client timed out while waiting for a response from the server. The server is no longer responding to keep-alive messages.";
            case MqttException.REASON_CODE_NO_MESSAGE_IDS_AVAILABLE:
                return "Internal error, caused by no new message IDs being available";
            case MqttException.REASON_CODE_WRITE_TIMEOUT:
                return "Client timed out while waiting to write messages to the server.";
            case MqttException.REASON_CODE_CLIENT_CONNECTED:
                return "The client is already connected";
            case MqttException.REASON_CODE_CLIENT_ALREADY_DISCONNECTED:
                return "The client is already disconnected";
            case MqttException.REASON_CODE_CLIENT_DISCONNECTING:
                return "The client is currently disconnecting and cannot accept any new work";
            case MqttException.REASON_CODE_SERVER_CONNECT_ERROR:
                return "Unable to connect to server";
            case MqttException.REASON_CODE_CLIENT_NOT_CONNECTED:
                return "The client is not connected to the server";
            case MqttException.REASON_CODE_SOCKET_FACTORY_MISMATCH:
                return "Server URI and supplied SocketFactory do not match.";
            case MqttException.REASON_CODE_SSL_CONFIG_ERROR:
                return "SSL configuration error.";
            case MqttException.REASON_CODE_CLIENT_DISCONNECT_PROHIBITED:
                return "Thrown when an attempt to call MqttClient.disconnect() has been made from within a method on MqttCallback";
            case MqttException.REASON_CODE_INVALID_MESSAGE:
                return "Protocol error: the message was not recognized as a valid MQTT packet";
            case MqttException.REASON_CODE_CONNECT_IN_PROGRESS:
                return "A connect operation in already in progress, only one connect can happen at a time";
            case MqttException.REASON_CODE_CLIENT_CLOSED:
                return "The client is closed - no operations are permitted on the client in this state. New up a new client to continue.";
            case MqttException.REASON_CODE_TOKEN_INUSE:
                return "A request has been made to use a token that is already associated with another action";
            case MqttException.REASON_CODE_MAX_INFLIGHT:
                return "A request has been made to send a message but the maximum number of inflight messages has already been reached";
            case MqttException.REASON_CODE_DISCONNECTED_BUFFER_FULL:
                return "The Client has attempted to publish a message whilst in the 'resting' / offline state";
        }


        return "Exception (" + reasonCode + ")";
    }

}

==> 0.5.7.tar.gz: android/src/main/java/com/samelement/iot_notification/service/MqttExceptionMessage.java <==
package com.samelement.iot_notification.service;

import org.eclipse.paho.client.mqttv3.MqttException;

public class MqttExceptionMessage {
    static String getMessage(MqttException exception, int reasonCode) {
        switch (reasonCode) {
            case MqttException.REASON_CODE_CLIENT_EXCEPTION:
                return "Client encountered an exception";
            case MqttException.REASON_CODE_CONNECTION_LOST:
                return "The client has been unexpectedly disconnected from the server";
            case MqttException.REASON_CODE_INVALID_PROTOCOL_VERSION:
                return "The protocol version requested is not supported by the server";
            case MqttException.REASON_CODE_INVALID_CLIENT_ID:
                return "The server has rejected the supplied client ID";
            case MqttException.REASON_CODE_BROKER_UNAVAILABLE:
                return "The broker was not available to handle the request";
            case MqttException.REASON_CODE_FAILED_AUTHENTICATION:
                return "Authentication with the server has failed, due to a bad user name or password";
            case MqttException.REASON_CODE_NOT_AUTHORIZED:
                return "Not authorized to perform the requested operation";
            case MqttException.REASON_CODE_UNEXPECTED_ERROR:
                return "An unexpected error has occurred";
            case MqttException.REASON_CODE_SUBSCRIBE_FAILED:
                return "Error from subscribe - returned from the server";
            case MqttException.REASON_CODE_CLIENT_TIMEOUT:
                return "Client timed out while waiting for a response from the server. The server is no longer responding to keep-alive messages.";
            case MqttException.REASON_CODE_NO_MESSAGE_IDS_AVAILABLE:
                return "Internal error, caused by no new message IDs being available";
            case MqttException.REASON_CODE_WRITE_TIMEOUT:
                return "Client timed out while waiting to write messages to the server.";
            case MqttException.REASON_CODE_CLIENT_CONNECTED:
                return "The client is already connected";
            case MqttException.REASON_CODE_CLIENT_ALREADY_DISCONNECTED:
                return "The client is already disconnected";
            case MqttException.REASON_CODE_CLIENT_DISCONNECTING:
                return "The client is currently disconnecting and cannot accept any new work";
            case MqttException.REASON_CODE_SERVER_CONNECT_ERROR:
                return "Unable to connect to server";
            case MqttException.REASON_CODE_CLIENT_NOT_CONNECTED:
                return "The client is not connected to the server";
            case MqttException.REASON_CODE_SOCKET_FACTORY_MISMATCH:
                return "Server URI and supplied SocketFactory do not match.";
            case MqttException.REASON_CODE_SSL_CONFIG_ERROR:
                return "SSL configuration error.";
            case MqttException.REASON_CODE_CLIENT_DISCONNECT_PROHIBITED:
                return "Thrown when an attempt to call MqttClient.disconnect() has been made from within a method on MqttCallback";
            case MqttException.REASON_CODE_INVALID_MESSAGE:
                return "Protocol error: the message was not recognized as a valid MQTT packet";
            case MqttException.REASON_CODE_CONNECT_IN_PROGRESS:
                return "A connect operation in already in progress, only one connect can happen at a time";
            case MqttException.REASON_CODE_CLIENT_CLOSED:
                return "The client is closed - no operations are permitted on the client in this state. New up a new client to continue.";
            case MqttException.REASON_CODE_TOKEN_INUSE:
                return "A request has been made to use a token that is already associated with another action";
            case MqttException.REASON_CODE_MAX_INFLIGHT:
                return "A request has been made to send a message but the maximum number of inflight messages has already been reached";
            case MqttException.REASON_CODE_DISCONNECTED_BUFFER_FULL:
                return "The Client has attempted to publish a message whilst in the 'resting' / offline state";
        }


        return "Exception (" + reasonCode + ")";
    }

}
